==> sqlitestudio-3.1.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>Графический интерфейс для SQLiteStudio, менеджера баз данных SQLite.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Включает вывод отладочных сообщений в консоль (доступную по нажатию F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Перенаправляет отладочные сообщения в стандартный поток (принудительный отладочный режим).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Перенаправляет отладочные сообщения в указанный файл (принудительный отладочный режим).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation>файл журнала</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Включает вывод отладочных сообщений анализатора Lemon для автодополнения SQL кода.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Включает отладку каждого запроса SQL, посылаемого к любой базе данных.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Ограничивает сообщения запросов SQL только для указанной &lt;базы данных&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>база данных</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation>Включает отладку обработчика запросов SQLiteStudio.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Выводит список установленных в SQLiteStudio модулей и осуществляет выход.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation>Указывает основной файл конфигурации. Детальная информация содержится в инструкции на wiki-странице.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>SQLiteStudio settings file</source>
        <translation>Файл настроек SQLiteStudio</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>file</source>
        <translation>файл</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Database file to open</source>
        <translation>Файл базы данных для открытия</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <location filename="../main.cpp" line="110"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>Графический интерфейс для SQLiteStudio, менеджера баз данных SQLite.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Включает вывод отладочных сообщений в консоль (доступную по нажатию F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Перенаправляет отладочные сообщения в стандартный поток (принудительный отладочный режим).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Перенаправляет отладочные сообщения в указанный файл (принудительный отладочный режим).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>log file</source>
        <translation>файл журнала</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Включает вывод отладочных сообщений анализатора Lemon для автодополнения SQL кода.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Включает отладку каждого запроса SQL, посылаемого к любой базе данных.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Ограничивает сообщения запросов SQL только для указанной &lt;базы данных&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>database</source>
        <translation>база данных</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation>Включает отладку обработчика запросов SQLiteStudio.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Выводит список установленных в SQLiteStudio модулей и осуществляет выход.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation>Указывает основной файл конфигурации. Детальная информация содержится в инструкции на wiki-странице.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>SQLiteStudio settings file</source>
        <translation>Файл настроек SQLiteStudio</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>file</source>
        <translation>файл</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Database file to open</source>
        <translation>Файл базы данных для открытия</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Ошибка</translation>
    </message>
</context>
</TS>
